"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const globals_1 = require("@jest/globals");
const sql_1 = require("@deepkit/sql");
const type_1 = require("@deepkit/type");
const postgres_adapter_1 = require("../src/postgres-adapter");
globals_1.test('postgres custom type', async () => {
    const post = type_1.t.schema({
        id: type_1.t.number.autoIncrement.primary,
        slug: type_1.t.string.postgres({ type: 'VARCHAR(255)' }),
        content: type_1.t.string.postgres({ type: 'text' }),
    }, { name: 'post' });
    const adapter = new postgres_adapter_1.PostgresDatabaseAdapter({ host: '127.0.0.1', database: 'postgres', user: 'postgres' });
    const [postTable] = adapter.platform.createTables([post]);
    globals_1.expect(postTable.getColumn('slug').type).toBe('varchar');
    globals_1.expect(postTable.getColumn('slug').size).toBe(255);
    globals_1.expect(postTable.getColumn('content').type).toBe('text');
    await sql_1.schemaMigrationRoundTrip([post], adapter);
});
const user = type_1.t.schema({
    id: type_1.t.number.autoIncrement.primary,
    username: type_1.t.string.index({ unique: true }),
    created: type_1.t.date,
    deleted: type_1.t.boolean,
    logins: type_1.t.number,
}, { name: 'user' });
user.addIndex(['deleted'], '', { unique: true });
user.addIndex(['deleted', 'created']);
const post = type_1.t.schema({
    id: type_1.t.number.autoIncrement.primary,
    user: type_1.t.type(user).reference(),
    created: type_1.t.date,
    slag: type_1.t.string.index({ unique: true }),
    title: type_1.t.string,
    content: type_1.t.string,
}, { name: 'post' });
globals_1.test('postgres', async () => {
    await sql_1.schemaMigrationRoundTrip([user, post], new postgres_adapter_1.PostgresDatabaseAdapter({ host: 'localhost', database: 'postgres', user: 'postgres' }));
});
//# sourceMappingURL=migration.spec.js.map